@@ -31,16 +31,20 @@
 # SPDX-License-Identifier: Apache-2.0
 # ============================================================================
 #
+__author__ =    "Patrick Lehmann"
+__email__ =     "Paebbels@gmail.com"
+__copyright__ = "2014-2021, Patrick Lehmann, Unai Martinez-Corral"
+__license__ =   "Apache License, Version 2.0"
+__version__ =   "0.4.0"
+__keywords__ =  ["eda project", "model", "abstract", "xilinx", "vivado", "osvvm", "file set", "file group", "test bench", "test harness"]
+
 from os.path import relpath as path_relpath
 from pathlib import Path as pathlib_Path
 from typing import Dict, Union, Optional as Nullable, List, Iterable, Generator, Tuple, Any as typing_Any, Type
 
 from pySVModel import VerilogVersion, SystemVerilogVersion
+from pyTooling.Decorators import export
 from pyVHDLModel import VHDLVersion
-from pydecor import export
-
-
-__version__ = "0.3.1"
 
 
 @export
@@ -703,7 +707,7 @@ class FileSet:
 
 	@property
 	def FileSets(self) -> Dict[str, 'FileSet']:
-		"""Read-only property returning the a dictionary of sub-filesets."""
+		"""Read-only property returning the dictionary of sub-filesets."""
 		return self._fileSets
 
 	def Files(self, fileType: FileType = FileTypes.Any, fileSet: Union[bool, str, 'FileSet'] = None) -> Generator[File, None, None]:
@@ -1105,7 +1109,7 @@ class Design:
 	# TODO: return generator with another method
 	@property
 	def FileSets(self) -> Dict[str, FileSet]:
-		"""Read-only property returning the a dictionary of filesets."""
+		"""Read-only property returning the dictionary of filesets."""
 		return self._fileSets
 
 	def Files(self, fileType: FileType = FileTypes.Any, fileSet: Union[str, FileSet] = None) -> Generator[File, None, None]:
